Module glob_utils

Module glob_utils 

Glob pattern matching utilities for path filtering Glob pattern matching utilities for path filtering

Functions

compile_patterns
Compile multiple glob patterns into matchers for efficient repeated matching
matches_any_matcher
Check if a path matches any of the precompiled glob matchers
matches_any_pattern
Check if a file path matches any of the given glob patterns