pub struct PlatformPaths;Expand description
Platform-agnostic path utilities
Implementations
Sourceimpl PlatformPaths
impl PlatformPaths
Sourcepub fn data_dir() -> PathBuf
pub fn data_dir() -> PathBuf
Get the appropriate data directory for the current platform
- Windows: %LOCALAPPDATA%
- macOS: ~/Library/Application Support
- Linux/Unix: $XDG_DATA_HOME or ~/.local/share
Sourcepub fn cache_dir() -> PathBuf
pub fn cache_dir() -> PathBuf
Get the appropriate cache directory for the current platform
- Windows: %LOCALAPPDATA%
- macOS: ~/Library/Caches
- Linux/Unix: $XDG_CACHE_HOME or ~/.cache
Sourcepub fn config_dir() -> PathBuf
pub fn config_dir() -> PathBuf
Get the appropriate config directory for the current platform
- Windows: %APPDATA%
- macOS: ~/Library/Application Support
- Linux/Unix: $XDG_CONFIG_HOME or ~/.config
Sourcepub fn project_folder_name() -> &'static str
pub fn project_folder_name() -> &'static str
Get the project folder name
Returns: “project-rag”
Sourcepub fn project_data_dir() -> PathBuf
pub fn project_data_dir() -> PathBuf
Get default project-specific data directory
Returns: {data_dir}/{project_folder_name}
Sourcepub fn project_cache_dir() -> PathBuf
pub fn project_cache_dir() -> PathBuf
Get default project-specific cache directory
Returns: {cache_dir}/{project_folder_name}
Sourcepub fn project_config_dir() -> PathBuf
pub fn project_config_dir() -> PathBuf
Get default project-specific config directory
Returns: {config_dir}/{project_folder_name}
Sourcepub fn default_lancedb_path() -> PathBuf
pub fn default_lancedb_path() -> PathBuf
Get default LanceDB database path
Returns: {data_dir}/{project_folder_name}/lancedb
Sourcepub fn default_hash_cache_path() -> PathBuf
pub fn default_hash_cache_path() -> PathBuf
Get default hash cache path
Returns: {cache_dir}/{project_folder_name}/hash_cache.json
Sourcepub fn default_git_cache_path() -> PathBuf
pub fn default_git_cache_path() -> PathBuf
Get default git cache path
Returns: {cache_dir}/{project_folder_name}/git_cache.json
Sourcepub fn default_config_path() -> PathBuf
pub fn default_config_path() -> PathBuf
Get default config file path
Returns: {config_dir}/{project_folder_name}/config.toml