Module types

Module types 

Type definitions for code relationships (definitions, references, call graphs).

This module provides the core data structures for representing code relationships:

  • SymbolId: Unique identifier for a symbol in the codebase
  • Definition: A symbol definition (function, class, method, etc.)
  • Reference: A reference to a symbol
  • CallEdge: An edge in the call graph

Structs

CallEdge
An edge in the call graph representing a function/method call.
CallGraphNode
A node in the call graph
Definition
A definition of a symbol in the codebase.
DefinitionResult
Result from find_definition containing the found definition
Reference
A reference to a symbol from another location in the codebase.
ReferenceResult
Result from find_references containing a found reference
SymbolId
A unique identifier for a symbol in the codebase.
SymbolInfo
Symbol info for call graph root

Enums

PrecisionLevel
Precision level of the relations provider
ReferenceKind
Kind of reference to a symbol
SymbolKind
Kind of symbol in the codebase
Visibility
Visibility/access modifier for a symbol