Glob pattern matching utilities for path filtering Glob pattern matching utilities for path filtering
Functions
- compile_
patterns - Compile multiple glob patterns into matchers for efficient repeated matching
- matches_
any_ matcher - Check if a path matches any of the precompiled glob matchers
- matches_
any_ pattern - Check if a file path matches any of the given glob patterns