Type definitions for code relationships (definitions, references, call graphs).
This module provides the core data structures for representing code relationships:
SymbolId: Unique identifier for a symbol in the codebaseDefinition: A symbol definition (function, class, method, etc.)Reference: A reference to a symbolCallEdge: An edge in the call graph
Structs
- Call
Edge - An edge in the call graph representing a function/method call.
- Call
Graph Node - A node in the call graph
- Definition
- A definition of a symbol in the codebase.
- Definition
Result - Result from find_definition containing the found definition
- Reference
- A reference to a symbol from another location in the codebase.
- Reference
Result - Result from find_references containing a found reference
- Symbol
Id - A unique identifier for a symbol in the codebase.
- Symbol
Info - Symbol info for call graph root
Enums
- Precision
Level - Precision level of the relations provider
- Reference
Kind - Kind of reference to a symbol
- Symbol
Kind - Kind of symbol in the codebase
- Visibility
- Visibility/access modifier for a symbol